@@ -1,5 +1,7 @@
 from __future__ import annotations  # todo0 remove in 3.11
 
+__all__ = ['DiscordBot']
+
 import asyncio
 import io
 import pathlib
@@ -199,11 +201,15 @@ class DiscordBot(MultiBot[Bot]):
             return
 
         if media.url:
-            if (path_suffix := pathlib.Path(media.url).suffix) and len(path_suffix) <= constants.MAX_FILE_EXTENSION_LENGHT:
-                file = discord.File(media.url)
+            if pathlib.Path(media.url).is_file():
+                if (path_suffix := pathlib.Path(media.url).suffix) and len(path_suffix) <= constants.MAX_FILE_EXTENSION_LENGHT:
+                    return discord.File(media.url)
+                else:
+                    return discord.File(media.url, filename=f'bot_media.{media.type_.extension}')
             else:
-                file = discord.File(media.url, filename=f'bot_media.{media.type_.extension}')
-        elif bytes_ := media.bytes_:
+                media.bytes_ = await flanautils.get_request(media.url)
+
+        if bytes_ := media.bytes_:
             if media.type_ is MediaType.GIF:
                 bytes_ = await flanautils.mp4_to_gif(bytes_)
             file = discord.File(fp=io.BytesIO(bytes_), filename=f'bot_media.{media.type_.extension}')
@@ -280,12 +286,14 @@ class DiscordBot(MultiBot[Bot]):
         message_to_delete.save()
 
     @return_if_first_empty(exclude_self_types='DiscordBot', globals_=globals())
-    async def get_chat(self, chat: int | str | Chat | Message = None) -> Chat | None:
+    async def get_chat(self, chat: int | str | User | Chat | Message = None) -> Chat | None:
         match chat:
             case int(chat_id):
                 pass
             case str(chat_name):
                 chat_id = Chat.find_one({'platform': self.platform.value, 'name': chat_name}).id
+            case User() as user:
+                return await self._create_chat_from_discord_chat(await user.original_object.create_dm())
             case Chat():
                 return chat
             case Message() as message:
@@ -298,7 +306,9 @@ class DiscordBot(MultiBot[Bot]):
 
     @return_if_first_empty(exclude_self_types='DiscordBot', globals_=globals())
     async def get_group_roles(self, group_: int | str | Chat | Message) -> list[Role]:
-        guild = await self._get_discord_group(group_)
+        if not (guild := await self._get_discord_group(group_)):
+            return []
+
         # noinspection PyTypeChecker
         return [Role(self.platform.value, discord_role.id, discord_role.name, discord_role.permissions.administrator, discord_role) for discord_role in guild.roles]
 
@@ -383,7 +393,10 @@ class DiscordBot(MultiBot[Bot]):
         text='',
         media: Media = None,
         buttons: list[str | list[str]] | None = None,
+        chat: int | str | User | Chat | Message | None = None,
         message: Message = None,
+        *,
+        reply_to: int | str | Message = None,
         silent: bool = False,
         send_as_file: bool = None,
         edit=False
@@ -415,8 +428,16 @@ class DiscordBot(MultiBot[Bot]):
             message.original_object = await message.original_object.edit(content=text, **kwargs)
             return message
         else:
+            match reply_to:
+                case int(message_id):
+                    reply_to = await chat.original_object.fetch_message(message_id)
+                case str(message_id):
+                    reply_to = await chat.original_object.fetch_message(int(message_id))
+                case Message() as message_to_reply:
+                    reply_to = message_to_reply.original_object
+
             try:
-                bot_message = await self._get_message(await message.chat.original_object.send(text, file=file, view=create_view()))
+                bot_message = await self._get_message(await chat.original_object.send(text, file=file, view=create_view(), reference=reply_to))
             except discord.errors.HTTPException:
                 if random.randint(0, 10):
                     error_message = 'El archivo pesa más de 8 MB.'
