@@ -1,5 +1,19 @@
 from __future__ import annotations  # todo0 remove in 3.11
 
+__all__ = [
+    'find_message',
+    'admin',
+    'block',
+    'bot_mentioned',
+    'group',
+    'ignore_self_message',
+    'inline',
+    'out_of_service',
+    'parse_arguments',
+    'reply',
+    'MultiBot'
+]
+
 import datetime
 import functools
 import random
@@ -131,27 +145,19 @@ def out_of_service(func: Callable) -> Callable:
 def parse_arguments(func: Callable) -> Callable:
     @functools.wraps(func)
     async def wrapper(*args, **kwargs) -> Any:
-        bot: MultiBot | None = None
+        self: MultiBot | None = None
         text = ''
         media: Media | None = None
         buttons: list[str | list[str]] | None = None
+        chat: int | str | User | Chat | Message | None = None
         message: Message | None = None
-        silent: bool | None = None
-        send_as_file: bool | None = None
-        edit = False
 
         for arg in args:
             match arg:
-                case MultiBot() as bot:
+                case MultiBot() as self:
                     pass
                 case str(text):
                     pass
-                case bool(silent):
-                    pass
-                case bool(send_as_file):
-                    pass
-                case bool(edit):
-                    pass
                 case int() | float() as number:
                     text = str(number)
                 case Media() as media:
@@ -162,23 +168,38 @@ def parse_arguments(func: Callable) -> Callable:
                     buttons = list(buttons)
                     for i, buttons_row in enumerate(buttons):
                         buttons[i] = list(buttons_row)
+                case User() as user:
+                    chat = user
                 case Chat() as chat:
-                    message = Message(chat=chat)
+                    pass
                 case Message() as message:
                     pass
 
-        silent = silent if (kw_value := kwargs.get('silent')) is None else kw_value
-        send_as_file = send_as_file if (kw_value := kwargs.get('send_as_file')) is None else kw_value
-        edit = edit if (kw_value := kwargs.get('edit')) is None else kw_value
+        chat = await self.get_chat(kwargs.get('chat', chat))
+        reply_to = kwargs.get('reply_to', None)
+        edit = kwargs.get('edit', None)
 
-        if edit is None:
-            args = (bot, text, media, buttons, message)
-            kwargs |= {'silent': silent, 'send_as_file': send_as_file}
-        else:
-            args = (bot, text, media, buttons, message)
-            kwargs |= {'silent': silent, 'send_as_file': send_as_file, 'edit': edit}
+        if reply_to is not None:
+            if chat:
+                raise TypeError('chat and reply_to parameters can not be setted at the same time')
+            if edit is not None:
+                raise TypeError('reply_to and edit parameters can not be setted at the same time')
 
-        return await func(*args, **kwargs)
+        if not chat:
+            if isinstance(reply_to, Message) and reply_to.chat:
+                chat = reply_to.chat
+            elif message:
+                chat = message.chat
+
+        if not message and isinstance(reply_to, Message):
+            message = reply_to
+
+        for arg_name in ('self', 'text', 'media', 'buttons', 'message'):
+            if arg_name not in kwargs:
+                kwargs[arg_name] = locals()[arg_name]
+        kwargs['chat'] = chat
+
+        return await func(**kwargs)
 
     return wrapper
 
@@ -297,7 +318,7 @@ class MultiBot(Generic[T], ABC):
     @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
     async def _get_message(self, event: constants.MESSAGE_EVENT) -> Message:
         original_message = event if isinstance(event, constants.ORIGINAL_MESSAGE) else await self._get_original_message(event)
-
+        print()
         message = Message(
             platform=self.platform,
             id=await self._get_message_id(original_message),
@@ -515,7 +536,7 @@ class MultiBot(Generic[T], ABC):
         return await self.send(*args, **kwargs)
 
     @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_chat(self, chat: int | str | Chat | Message) -> Chat | None:
+    async def get_chat(self, chat: int | str | User | Chat | Message) -> Chat | None:
         pass
 
     @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
@@ -649,7 +670,7 @@ class MultiBot(Generic[T], ABC):
 
     @abstractmethod
     @parse_arguments
-    async def send(self, text='', media: Media = None, buttons: list[str | list[str]] | None = None, message: Message = None, silent: bool = False, send_as_file: bool = None, edit=False, **_kwargs) -> Message | None:
+    async def send(self, text='', media: Media = None, buttons: list[str | list[str]] | None = None, chat: int | str | User | Chat | Message | None = None, message: Message = None, *, reply_to: int | str | Message = None, silent: bool = False, send_as_file: bool = None, edit=False) -> Message | None:
         pass
 
     @parse_arguments
